@@ -264,7 +264,11 @@ get_mirror_info () {
 		MIRROR=""
 		DIRECTORY="/cdrom/"
 		if [ -s /cdrom/.disk/base_components ]; then
-			COMPONENTS=`grep -v '^#' /cdrom/.disk/base_components | tr '\n' , | sed 's/,$//'`
+			if db_get apt-setup/restricted && [ "$RET" = false ]; then
+				COMPONENTS=`grep -v '^#' /cdrom/.disk/base_components | egrep -v '^(restricted|multiverse)$' | tr '\n' , | sed 's/,$//'`
+			else
+				COMPONENTS=`grep -v '^#' /cdrom/.disk/base_components | tr '\n' , | sed 's/,$//'`
+			fi
 		else
 			COMPONENTS="*"
 		fi
@@ -299,7 +303,11 @@ get_mirror_info () {
 		db_get mirror/$PROTOCOL/directory || mirror_error=1
 		DIRECTORY="$RET"
 
-		COMPONENTS="main,restricted"
+		if db_get apt-setup/restricted && [ "$RET" = false ]; then
+			COMPONENTS="main"
+		else
+			COMPONENTS="main,restricted"
+		fi
 
 		if [ "$mirror_error" = 1 ] || [ -z "$PROTOCOL" ] || [ -z "$MIRROR" ]; then
 			exit_error base-installer/cannot_install
@@ -753,6 +761,9 @@ EOT
 		if ! log-output -t base-installer chroot /target apt-cdrom add ; then
 			error "error while running apt-cdrom"
 		fi
+		if db_get apt-setup/restricted && [ "$RET" = false ]; then
+			sed -i 's/ \(restricted\|multiverse\)//g' /target/etc/apt/sources.list
+		fi
 	else
 		echo "deb $APTSOURCE $DISTRIBUTION $COMPONENTS" > /target/etc/apt/sources.list
 		echo "deb $APTSOURCE $DISTRIBUTION-updates $COMPONENTS" >> /target/etc/apt/sources.list
@@ -761,7 +772,7 @@ EOT
 		else
 			SECMIRROR="$MIRROR"
 		fi
-		echo "deb $PROTOCOL://$MIRROR/ubuntu $DISTRIBUTION-security $COMPONENTS" >> /target/etc/apt/sources.list
+		echo "deb $PROTOCOL://$SECMIRROR/ubuntu $DISTRIBUTION-security $COMPONENTS" >> /target/etc/apt/sources.list
 		if db_get apt-setup/proposed && [ "$RET" = true ]; then
 			echo "deb $APTSOURCE $DISTRIBUTION-proposed $COMPONENTS" >> /target/etc/apt/sources.list
 		fi
