@@ -658,7 +658,7 @@ class Install:
             if self.db.get('oem-config/enable') == 'true':
                 oem_id = self.db.get('oem-config/id')
                 oem_id_file = open(
-                    os.path.join(self.target, 'var/log/installer/oem-id'))
+                    os.path.join(self.target, 'var/log/installer/oem-id'), 'w')
                 print >>oem_id_file, oem_id
                 oem_id_file.close()
         except (debconf.DebconfError, IOError):
@@ -1726,8 +1726,10 @@ exit 0"""
                         if os.path.exists(os.path.join(self.target,
                                                        desktop_file)):
                             desktop_base = os.path.basename(desktop_file)
-                            self.chrex('install', '-D',
+                            self.chrex('install', '-d',
                                        '-o', 'oem', '-g', 'oem',
+                                       '/home/oem/Desktop')
+                            self.chrex('install', '-o', 'oem', '-g', 'oem',
                                        '/%s' % desktop_file,
                                        '/home/oem/Desktop/%s' % desktop_base)
                             break
