@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-# Copyright (C) 2005, 2006 Canonical Ltd.
+# Copyright (C) 2005, 2006, 2007, 2008 Canonical Ltd.
 # Written by Tollef Fog Heen <tfheen@ubuntu.com> and
 # Colin Watson <cjwatson@ubuntu.com>
 #
@@ -20,6 +20,7 @@
 
 import re
 import os
+
 from ubiquity.filteredcommand import FilteredCommand
 from ubiquity import keyboard_names
 from ubiquity import misc
@@ -32,6 +33,7 @@ class ConsoleSetup(FilteredCommand):
         # will think it's already configured and behave differently. Try to
         # save the old file for interest's sake, but it's not a big deal if
         # we can't.
+        misc.regain_privileges()
         try:
             os.unlink('/etc/default/console-setup.pre-ubiquity')
         except OSError:
@@ -44,6 +46,7 @@ class ConsoleSetup(FilteredCommand):
                 os.unlink('/etc/default/console-setup')
             except OSError:
                 pass
+        misc.drop_privileges()
         # Make sure debconf doesn't do anything with crazy "preseeded"
         # answers to these questions. If you want to preseed these, use the
         # *code variants.
@@ -56,7 +59,8 @@ class ConsoleSetup(FilteredCommand):
         # bother for now.
         return (['/usr/lib/ubiquity/console-setup/console-setup.postinst',
                  'configure'],
-                ['^console-setup/layout', '^console-setup/variant'])
+                ['^console-setup/layout', '^console-setup/variant'],
+                {'OVERRIDE_ALLOW_PRESEEDING': '1'})
 
     def run(self, priority, question):
         if self.done:
@@ -78,7 +82,15 @@ class ConsoleSetup(FilteredCommand):
             self.frontend.set_keyboard_variant_choices(
                 self.choices_untranslated(question))
             self.frontend.set_keyboard_variant(self.db.get(question))
-            return FilteredCommand.run(self, priority, question)
+            # console-setup preseeding is special, and needs to be checked
+            # by hand. The seen flag on console-setup/layout is used
+            # internally by console-setup, so we can't just force it to
+            # true.
+            if ('UBIQUITY_AUTOMATIC' in os.environ and
+                self.db.fget('console-setup/layoutcode', 'seen') == 'true'):
+                return True
+            else:
+                return FilteredCommand.run(self, priority, question)
         else:
             return True
 
@@ -111,35 +123,57 @@ class ConsoleSetup(FilteredCommand):
                       'th', 'tj', 'tam', 'ua', 'uz'):
             latin = False
             real_layout = 'us,%s' % layout
-        elif layout == 'cs':
-            if variant.startswith('latin'):
-                latin = True
-                real_layout = layout
-            else:
-                latin = False
-                real_layout = 'cs,cs'
         elif layout == 'jp':
-            if variant == 'latin':
+            if variant in ('106', 'common', 'OADG109A', 'nicola_f_bs'):
                 latin = True
                 real_layout = layout
             else:
                 latin = False
                 real_layout = 'jp,jp'
+        elif layout == 'lt':
+            latin = False
+            real_layout = 'lt,lt'
+        elif layout == 'me':
+            if variant == 'basic' or variant.startswith('latin'):
+                latin = True
+                real_layout = layout
+            else:
+                latin = False
+                real_layout = 'me,me'
+        elif layout == 'rs':
+            if variant == 'basic' or variant.startswith('latin'):
+                latin = True
+                real_layout = layout
+            else:
+                latin = False
+                real_layout = 'rs,rs'
         else:
             latin = True
             real_layout = layout
 
         if latin:
             real_variant = variant
-        elif real_layout == 'cs,cs':
+        elif real_layout == 'jp,jp':
+            real_variant = '106,%s' % variant
+        elif real_layout == 'lt,lt':
+            if variant == 'us':
+                real_variant = 'us,'
+            else:
+                real_variant = '%s,us' % variant
+        elif real_layout == 'me,me':
+            if variant == 'cyrillicyz':
+                real_variant = 'latinyz,%s' % variant
+            elif variant == 'cyrillicalternatequotes':
+                real_variant = 'latinalternatequotes,%s' % variant
+            else:
+                real_variant = 'basic,%s' % variant
+        elif real_layout == 'rs,rs':
             if variant == 'yz':
                 real_variant = 'latinyz,%s' % variant
             elif variant == 'alternatequotes':
                 real_variant = 'latinalternatequotes,%s' % variant
             else:
                 real_variant = 'latin,%s' % variant
-        elif real_layout == 'jp,jp':
-            real_variant = 'latin,%s' % variant
         else:
             real_variant = ',%s' % variant
 
@@ -187,7 +221,7 @@ class ConsoleSetup(FilteredCommand):
             args.extend(("-variant", variant))
         for option in options:
             args.extend(("-option", option))
-        misc.ex("setxkbmap", *args)
+        misc.execute("setxkbmap", *args)
 
     def cleanup(self):
         # TODO cjwatson 2006-09-07: I'd use dexconf, but it seems reasonable
@@ -205,6 +239,7 @@ class ConsoleSetup(FilteredCommand):
         if layout == '':
             return
 
+        misc.regain_privileges()
         oldconfigfile = '/etc/X11/xorg.conf'
         newconfigfile = '/etc/X11/xorg.conf.new'
         try:
@@ -287,3 +322,4 @@ class ConsoleSetup(FilteredCommand):
         newconfig.close()
         oldconfig.close()
         os.rename(newconfigfile, oldconfigfile)
+        misc.drop_privileges()
