@@ -31,7 +31,7 @@ from ubiquity.filteredcommand import FilteredCommand
 def grub_options():
     """ Generates a list of suitable targets for grub-installer
         @return empty list or a list of ['/dev/sda1','Ubuntu Hardy 8.04'] """
-    os.seteuid(0)
+    regain_privileges()
     l = []
     oslist = {}
     subp = subprocess.Popen(['os-prober'], stdout=subprocess.PIPE,
